@@ -1,5 +1,5 @@
 package Test::Mock::Two;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 use warnings;
 use strict;
 
@@ -43,7 +43,7 @@ sub one_called {
         my $rv = $cs->{$method};
 
         return unless $rv;
-        return $rv if !$func;
+        return $rv if !defined $func;
 
         return $rv->{$func} if exists $rv->{$func};
     }
@@ -96,7 +96,7 @@ Test::Mock::Two - Inspection module for Test::Mock::One
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
